Package: MMRcaseselection
Type: Package
Title: Case Classification and Selection Based on Regression Results
Version: 0.2.0
Authors@R: 
    person("Ingo", "Rohlfing", email = "ingo.rohlfing@uni-passau.de",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-8715-4771"))
Depends: R (>= 2.10)
Description: Researchers doing a mixed-methods analysis (nested analysis as
    developed by Lieberman (2005) <doi:10.1017/S0003055405051762>) can
    use the package for the classification of cases and case selection using
    results of a linear regression. One can designate cases 
    as typical, deviant, extreme and pathway case and use different case 
    selection strategies for the choice of a case belonging to one of
    these types.
License: GPL-3
Encoding: UTF-8
Imports: stats, ggplot2
URL: https://github.com/ingorohlfing/MMRcaseselection
BugReports: https://github.com/ingorohlfing/MMRcaseselection/issues
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-17 17:35:46 UTC; ingor
Author: Ingo Rohlfing [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-8715-4771>)
Maintainer: Ingo Rohlfing <ingo.rohlfing@uni-passau.de>
Repository: CRAN
Date/Publication: 2026-05-21 09:32:15 UTC
Built: R 4.6.0; ; 2026-05-25 03:35:20 UTC; unix
