# Generated by roxygen2: do not edit by hand

export(extreme_on_x)
export(extreme_on_y)
export(most_deviant)
export(most_overpredicted)
export(most_typical)
export(most_underpredicted)
export(pathway)
export(pathway_xvr)
export(predint)
export(predint_plot)
export(residstd)
export(residstd_plot)
import(ggplot2)
importFrom(stats,lm)
importFrom(stats,predict.lm)
importFrom(stats,residuals)
