# MMRcaseselection <img src="man/figures/MMRhex.png" height="200" align="right">

[![CRAN
status](http://www.r-pkg.org/badges/version/MMRcaseselection)](https://cran.r-project.org/package=MMRcaseselection)
[![Project Status: Active – The project has reached a stable, usable state and is being actively developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![GPLv3 License](https://img.shields.io/badge/License-GPL%20v3-yellow.svg)](https://opensource.org/license)
![](https://cranlogs.r-pkg.org/badges/grand-total/MMRcaseselection)

## Overview
Classification and choice of cases for case studies based on regression results.

For now, the package contains functions for the classification of cases as 
typical, deviant, extreme or pathway cases and the choice of these types of cases. 
At this stage, the focus is on single cases and case selection based on linear regression models (class `lm`).

The package is [available on CRAN](https://cran.r-project.org/package=MMRcaseselection). 
The version on CRAN Github is 0.2.0. The package can be installed from CRAN with the following command.

```r
install.packages("MMRcaseselection")
```

The package can be installed from Github with the following command.

```r
pak::pak("ingorohlfing/MMRcaseselection")
```

The documentation of the package and examples can be found 
[here](https://ingorohlfing.github.io/MMRcaseselection/docs/). Please open an
issue on Github if problems come up.

***

Work on the package was funded by the European Research Council (ERC) under the 
European Union’s Horizon 2020 research and innovation program (grant agreement 
number 638425, *Enhanced Qualitative and Multimethod Research*).

